@@ -1,4 +1,4 @@
 from .vit_mlp import ViTMLP
 from .vit_moe_mlp import MLPForMoe
-from .detr_mlp import DetrMLP
+from .detr_mlp import DeTrMLP
 from .transformer_mlp import TransformerMLP
