@@ -1,4 +1,4 @@
-from . import detr
+# from . import detr
 from . import gpt
 from . import knowledge_graph_embedding
 from . import moe
@@ -6,4 +6,4 @@ from . import transformer
 from . import vilt
 from . import vit
 
-__all__ = ['detr', 'gpt', 'knowledge_graph_embedding', 'moe', 'transformer', 'vilt', 'vit']
\ No newline at end of file
+__all__ = ['detr', 'gpt', 'knowledge_graph_embedding', 'moe', 'transformer', 'vilt', 'vit']
